"""A position in the two-dimensional integer lattice."""
from seligimus.maths.vector_2 import Vector2


class IntegerPosition2D(Vector2[int]):  # pylint: disable=too-few-public-methods
    """A position in the two-dimensional integer lattice."""
